@@ -5,7 +5,7 @@
 import numpy as np
 import os
 from os.path import join, isdir, isfile
-from gwalk.data.database import Database
+from xdata import Database
 from gwalk.catalog.coordinates import coord_tags as COORD_TAGS
 from gwalk.catalog.coordinates import coord_labels as COORD_LABELS
 from gwalk.catalog.coordinates import q_of_mc_eta
