@@ -837,13 +837,25 @@ class Mesh(object):
         lnL_norm = MV.likelihood(
                                  y_mesh,
                                  X=X,
-                                 scale=MV.scale,
                                  indices=[index],
                                  log_scale=True,
                                 )
 
-        # Calculate the kl divergence
-        kl = relative_entropy_alt(L_mesh, lnL_mesh, lnL_norm)
+        # Identify the parts to keep
+        keep = np.isfinite(lnL_norm)
+        keep = np.prod(keep,axis=0).astype(bool)
+        keep_tile = np.tile(keep,(lnL_norm.shape[0],1))
+        # Update the scaling constant
+        L_sum = np.sum(L_mesh[keep])
+        # Update lnL_norm
+        lnL_norm = lnL_norm[keep_tile].reshape(lnL_norm.shape[0],np.sum(keep))
+        #print(lnL_mesh[keep])
+        #print(lnL_norm)
+        kl = relative_entropy_alt(
+                                  L_mesh[keep]/L_sum,
+                                  lnL_mesh[keep]-np.log(L_sum),
+                                  lnL_norm
+                                 )
         return kl
 
 
@@ -883,12 +895,23 @@ class Mesh(object):
         lnL_norm = MV.likelihood(
                                  y_mesh,
                                  X=X,
-                                 scale=MV.scale,
                                  indices=[index,jndex],
                                  log_scale=True,
                                 )
-        # Calculate the kl divergence
-        kl = relative_entropy_alt(L_mesh, lnL_mesh, lnL_norm)
+        keep = np.isfinite(lnL_norm)
+        keep = np.prod(keep,axis=0).astype(bool)
+        keep_tile = np.tile(keep,(lnL_norm.shape[0],1))
+        # Update the scaling constant
+        L_sum = np.sum(L_mesh[keep])
+        # Update lnL_norm
+        lnL_norm = lnL_norm[keep_tile].reshape(lnL_norm.shape[0],np.sum(keep))
+        #print(lnL_mesh[keep])
+        #print(lnL_norm)
+        kl = relative_entropy_alt(
+                                  L_mesh[keep]/L_sum,
+                                  lnL_mesh[keep]-np.log(L_sum),
+                                  lnL_norm
+                                 )
         return kl
 
     def nal_kl_div(
