@@ -19,6 +19,8 @@ def fit_grid(
              sig_factor=3.,
              objective="lstsq",
              method="L-BFGS-B",
+             norm_limit=None,
+             sig_max=None,
             ):
     ''' Fit multivariate normal object to samples with values
 
@@ -41,10 +43,13 @@ def fit_grid(
     sig_factor: float, optional
         Input controls jump sizes
     '''
+    # Check norm limit
+    if norm_limit is None:
+        norm_limit = (np.max(values) - np.min(values)) + np.mean(values)
     # Initialize grid
-    grid = Grid(sample, values, limits)
+    grid = Grid(sample, values, limits, norm_limit=norm_limit)
     # Generate a multivariate_normal object
-    MV = grid.construct_nal(seed=seed,labels=p_labels)
+    MV = grid.construct_nal(seed=seed,labels=p_labels,sig_max=sig_max)
     # Do simple fit
     grid.nal_fit_to_samples(MV)
     # Do a scipy optimize
